@@ -1,6 +1,4 @@
-﻿# This Python file uses the following encoding: utf-8
-
-Theme = {
+﻿Theme: dict = {
     "Colors": {
         "base": "#004d99",
         "second": "#0066cc",
@@ -35,13 +33,19 @@ Theme = {
         "border": 1,
         "borderBold": 2,
         "icon": 36,
+        "iconSmall": 16,
         "none": 0
     },
 
     "Animation": {
         "hover": 50,
         "quick": 250,
-        "medium": 500
+        "medium": 500,
+        "normal": 1000
+    },
+
+    "Time": {
+        "repeat": 5000
     },
 
     "FontSize": {
